@@ -6,8 +6,8 @@ require Exporter;
 
 use vars qw($VERSION @EXPORT_OK @ISA);
 
-$VERSION = '2.01';
-@EXPORT_OK = qw(parsefile parsedommish);
+$VERSION = '2.02';
+@EXPORT_OK = qw(parsefile);
 @ISA = qw(Exporter);
 
 # localising prevents the warningness leaking out of this module
@@ -152,62 +152,7 @@ A scalar piece of text.
 
 =back
 
-=head2 parsedommish
-
-This takes exactly the same parameters as C<parsefile()> but instead
-returns a XML::Tiny::DOMmish::Node object that you can query in a
-sort-of DOMmish way.
-
-It provides the following methods:
-
-=head3 various created by AUTOLOAD
-
-Given this XML:
-
-    <rsnapshot>
-      <snapshotroot nocreateroot='1'>
-        /.snapshots/
-      </snapshotroot>
-      <externalprograms>
-        <rsync binary='/usr/bin/rsync'>
-          <shortargs>
-            <arg>-a</arg>
-            <arg>-q</arg>
-          </shortargs>
-          <longargs>
-            <arg>--delete</arg>
-          </longargs>
-        </rsync>
-      </externalprograms>
-    </rsnapshot>
-
-then you can query it thus:
-
-    my $rsync = $document->externalprograms->rsync();
-    my $rsyncbinary = $rsync->binary();
-    my $secondshortarg = $rsync->shortargs->arg(1);
-    my @shortargs      = $rsync->shortargs->arg('*');
-
-The methods (eg C<binary>, C<rsync> etc) in the synopsis above are created
-using AUTOLOAD.  The AUTOLOADer first looks for an attribute with the
-appropriate name and if it exists, returns its contents.
-
-If no such attribute is found, then it looks for a child node of the
-appropriate type.  If no parameter is given, it returns the first one.
-
-If a numeric parameter is given it returns the Nth such node - they are
-numbered from 0.
-
-If the parameter is an asterisk (C<*>) then a list of all such nodes
-is returned.
-
-Otherwise the node of the appropriate type whose C<-E<gt>name()> method
-matches is returned.  It is an error to try this if there's no such
-method.
-
-Nodes stringify to their contents if necessary, and can also be compared
-for string (in)equality.  Note that when stringifying, leading and
-trailing whitespace is removed.
+If you prefer a DOMmish interface, then look at L<XML::Tiny::DOM> on the CPAN.
 
 =cut
 
@@ -217,9 +162,6 @@ my %regexps = (
 
 my $strict_entity_parsing; # mmm, global. don't worry, parsefile sets it
                            # explicitly every time
-sub parsedommish {
-    return XML::Tiny::DOMmish::Node->new(parsefile(@_)->[0]);
-}
 
 sub parsefile {
     my($arg, %params) = @_;
@@ -496,6 +438,8 @@ L<XML::Parser>
 
 L<XML::Parser::EasyTree>
 
+L<XML::Tiny::DOM>
+
 =item The requirements for a module to be Tiny
 
 L<http://beta.nntp.perl.org/group/perl.datetime/2007/01/msg6584.html>
@@ -534,75 +478,4 @@ This module is also free-as-in-mason software.
 
 =cut
 
-package XML::Tiny::DOMmish::Node;
-
-use vars qw($AUTOLOAD);
-use overload
-    '""'  => sub { return shift()->_gettext(); },
-    'eq'  => sub { my $s = shift(); return $s->_compare('eq', @_) },
-    'ne'  => sub { my $s = shift(); return $s->_compare('ne', @_) },
-    ;
-sub new {
-    my $class = shift;
-    my $document = shift;
-    bless $document, $class;
-}
-
-sub AUTOLOAD {
-    (my $nodename = $AUTOLOAD) =~ s/.*:://;
-    my $self   = shift();
-    my $wanted = shift() || 0;
-
-    # attribs take precedence ...
-    return $self->{attrib}->{$nodename}
-        if(exists($self->{attrib}->{$nodename}));
-
-    my @childnodes = ();
-    foreach my $childnode (@{$self->{content}}) {
-        if($childnode->{type} eq 'e' && $childnode->{name} eq $nodename) {
-            push @childnodes, __PACKAGE__->new($childnode);
-        }
-    }
-    if($wanted eq '*') {
-        return @childnodes;
-    } elsif($wanted =~ /^\d+$/) {
-        return $childnodes[$wanted] if(exists($childnodes[$wanted]));
-        die("Can't get '$nodename' number $wanted from object ".ref($self)."\n")
-;
-    } else {
-        return (grep { $_->name() eq $wanted } @childnodes)[0];
-    }
-}
-
-sub _gettext {
-    my $self = shift;
-    my $c = $self->{content};
-    if(
-        ref($c) eq 'ARRAY' && # there's some contents
-        $c->[0]->{type} eq 't' # it's a text node
-    ) {
-        (my $value = $c->[0]->{content}) =~ s/^\s+|\s+$//g;
-        return $value;
-    } else {
-        die("Can't stringify '".$self->{name}."' in ".ref($self)."\n");
-    }
-}
-
-sub _compare {
-    my($self, $op, $comparand, $reversed) = @_;
-    my $value = $self->_gettext();
-    ($value, $comparand) = ($comparand, $value) if($reversed);
-    return ($op eq 'eq') ? $value eq $comparand :
-           ($op eq 'ne') ? $value ne $comparand :
-           # ($op eq 'lt') ? $value lt $comparand :
-           # ($op eq 'le') ? $value le $comparand :
-           # ($op eq 'gt') ? $value gt $comparand :
-           # ($op eq 'ge') ? $value ge $comparand :
-           # ($op eq 'cmp') ? $value cmp $comparand :
-           die("_compare can't $op\n");
-}
-sub DESTROY {}
-
-
-
 '<one>zero</one>';
